#' shinyHugePlot
#'
#' An interactive plot for data with a large sample size using \code{shiny}
#' and\code{plotly} can be obtained.
#' For an easy application, see \code{shiny_hugeplot} function.
#' For a manual application, see \code{downsampler} class.
#' @name shinyHugePlot
#' @docType package
#' @import plotly
#' @import shiny
"_PACKAGE"
